==> vaycore-0.2.1.tar.gz: lib/http/net_request.dart <==
import 'package:vaycore/dio/default_adapter.dart';
import 'package:vaycore/http.dart';

///
/// @author vay
/// @email hxhvay@126.com
/// @date 2020-05-09
///

/// 解析器
typedef Parser<M> = M Function<M>(dynamic data);

/// 网络请求对象
class NetRequest {
  final BaseNetAdapter _adapter;
  List<dynamic> _interceptors;
  final Parser _parser;

  NetRequest({
    BaseNetAdapter adapter,
    List<dynamic> interceptors,
    Parser parser,
  })  : this._adapter = adapter ?? DefaultAdapter(),
        this._parser = parser,
        this._interceptors = interceptors;

  List<dynamic> get interceptors {
    if (_interceptors == null) {
      _interceptors = List();
    }
    return this._interceptors;
  }

  BaseNetAdapter get adapter => _adapter;

  /// Get请求
  Future<HttpResult<T>> get<T>(
    String url, {
    Map<String, dynamic> data,
    Map<String, dynamic> header,
    int retryCount = 3,
  }) {
    return this.request(url,
        method: HttpMethod.GET,
        data: data,
        header: header,
        retryCount: retryCount);
  }

  /// Post请求
  Future<HttpResult<T>> post<T>(
    String url, {
    Map<String, dynamic> data,
    Map<String, dynamic> header,
    int retryCount = 3,
  }) {
    return this.request(url,
        method: HttpMethod.POST,
        data: data,
        header: header,
        retryCount: retryCount);
  }

  /// Put请求
  Future<HttpResult<T>> put<T>(
    String url, {
    Map<String, dynamic> data,
    Map<String, dynamic> header,
    int retryCount = 3,
  }) {
    return this.request(url,
        method: HttpMethod.PUT,
        data: data,
        header: header,
        retryCount: retryCount);
  }

  /// Delete请求
  Future<HttpResult<T>> delete<T>(
    String url, {
    Map<String, dynamic> data,
    Map<String, dynamic> header,
    int retryCount = 3,
  }) {
    return this.request(url,
        method: HttpMethod.DELETE,
        data: data,
        header: header,
        retryCount: retryCount);
  }

  /// Head请求
  Future<HttpResult<T>> head<T>(
    String url, {
    Map<String, dynamic> data,
    Map<String, dynamic> header,
    int retryCount = 3,
  }) {
    return this.request(url,
        method: HttpMethod.HEAD,
        data: data,
        header: header,
        retryCount: retryCount);
  }

  /// Patch请求
  Future<HttpResult<T>> patch<T>(
    String url, {
    Map<String, dynamic> data,
    Map<String, dynamic> header,
    int retryCount = 3,
  }) {
    return this.request(url,
        method: HttpMethod.PATCH,
        data: data,
        header: header,
        retryCount: retryCount);
  }

  /// 网络请求
  Future<HttpResult<T>> request<T>(String url,
      {HttpMethod method = HttpMethod.GET,
      int timeout = 15000,
      String contentType = "application/json; charset=utf-8",
      dynamic responseType,
      Map<String, dynamic> data,
      Map<String, dynamic> header,
      int retryCount = 3,
      dynamic transformer,
      List<dynamic> interceptors,
      Parser<T> parser}) {
    assert(url != null && url.startsWith("http"));
    assert(_adapter != null);
    parser ??= this._parser;
    assert(parser != null);
    try {
      // 拦截器处理
      if (interceptors == null) {
        interceptors = List.from(this.interceptors);
      } else {
        interceptors?.insertAll(0, this.interceptors);
      }

      // 请求交给adapter处理
      return _adapter.request<T>(RequestParams.builder()
          .setUrl(url)
          .setMethod(method)
          .setHeader(header)
          .setTimeout(timeout)
          .setData(data)
          .setResponseType(responseType)
          .setTransformer(transformer)
          .setInterceptors(interceptors)
          .setParser(parser)
          .build());
    } catch (e) {
      return Future.value(HttpResult<T>(ResultStatus.intercept, error: e));
    }
  }
}

/// 网络请求适配器
abstract class BaseNetAdapter {
  /// 核心请求方法
  Future<HttpResult<T>> request<T>(RequestParams params);

  /// 将参数合并到url
  String wrapUrlByParams(
      HttpMethod method, String url, Map<String, dynamic> params) {
    // 只有GET请求、HEAD请求才会把参数拼接到url
    if (method != HttpMethod.GET && method != HttpMethod.HEAD) {
      return url;
    }
    if (url.contains("?")) {
      url = _handleUrlParams(url, params);
    }
    if (params != null && params.isNotEmpty) {
      StringBuffer sb = new StringBuffer();
      params.forEach((key, value) {
        if (sb.isEmpty) {
          sb.write("$url?");
        } else {
          sb.write("&");
        }
        sb.write("$key=$value");
      });
      return sb.toString();
    }
    return url;
  }

  /// 处理url原有的参数，如果包含参数，则返回的url会自动移除url追加的参数
  String _handleUrlParams(String url, Map<String, dynamic> params) {
    if (params == null || params.isEmpty) {
      return url;
    }
    Map<String, String> urlParams = Uri.parse(url)?.queryParameters;
    if (urlParams != null && urlParams.isNotEmpty) {
      urlParams.forEach((key, value) {
        if (key == null || key.isEmpty || value == null || value.isEmpty) {
          return;
        }
        if (!params.containsKey(key)) {
          params[key] = value;
        }
      });
      return url.split("?")[0];
    }
    return url;
  }
}

/// 请求结果对象
class HttpResult<T> {
  final ResultStatus status;
  final T data;
  final dynamic error;

  HttpResult(this.status, {this.data, this.error});
}

==> vaycore-0.5.1.tar.gz: lib/http/net_request.dart <==
import 'package:vaycore/dio/default_adapter.dart';
import 'package:vaycore/http.dart';

///
/// @author vay
/// @email hxhvay@126.com
/// @date 2020-05-09
///

/// 解析器
typedef Parser<M> = M Function<M>(dynamic data);

/// 网络请求对象
class NetRequest {
  final BaseNetAdapter _adapter;
  List<dynamic> _interceptors;
  final Parser _parser;

  NetRequest({
    BaseNetAdapter adapter,
    List<dynamic> interceptors,
    Parser parser,
  })
      : this._adapter = adapter ?? DefaultAdapter(),
        this._parser = parser,
        this._interceptors = interceptors;

  List<dynamic> get interceptors {
    if (_interceptors == null) {
      _interceptors = List();
    }
    return this._interceptors;
  }

  BaseNetAdapter get adapter => _adapter;

  /// 网络请求
  Future<HttpResult<T>> request<T>(String url,
      {HttpMethod method = HttpMethod.GET,
        int timeout = 15000,
        String contentType = "application/json; charset=utf-8",
        dynamic responseType,
        Map<String, dynamic> data,
        Map<String, dynamic> header,
        int retryCount = 3,
        dynamic transformer,
        List<dynamic> interceptors,
        Parser<T> parser}) {
    assert(url != null);
    assert(_adapter != null);
    parser ??= this._parser;
    assert(parser != null);
    try {
      // 拦截器处理
      if (interceptors == null) {
        interceptors = List.from(this.interceptors);
      } else {
        interceptors?.insertAll(0, this.interceptors);
      }

      // 请求交给adapter处理
      return _adapter.request<T>(RequestParams.builder()
          .setUrl(url)
          .setMethod(method)
          .setHeader(header)
          .setTimeout(timeout)
          .setData(data)
          .setResponseType(responseType)
          .setTransformer(transformer)
          .setInterceptors(interceptors)
          .setParser(parser)
          .build());
    } catch (e) {
      return Future.value(HttpResult<T>(ResultStatus.intercept, error: e));
    }
  }
}

/// 网络请求适配器
abstract class BaseNetAdapter {
  /// 核心请求方法
  Future<HttpResult<T>> request<T>(RequestParams params);

  /// 将参数合并到url
  String wrapUrlByParams(HttpMethod method, String url,
      Map<String, dynamic> params) {
    // 只有GET请求、HEAD请求才会把参数拼接到url
    if (method != HttpMethod.GET && method != HttpMethod.HEAD) {
      return url;
    }
    if (url.contains("?")) {
      url = _handleUrlParams(url, params);
    }
    if (params != null && params.isNotEmpty) {
      StringBuffer sb = new StringBuffer();
      params.forEach((key, value) {
        if (sb.isEmpty) {
          sb.write("$url?");
        } else {
          sb.write("&");
        }
        sb.write("$key=$value");
      });
      return sb.toString();
    }
    return url;
  }

  /// 处理url原有的参数，如果包含参数，则返回的url会自动移除url追加的参数
  String _handleUrlParams(String url, Map<String, dynamic> params) {
    if (params == null || params.isEmpty) {
      return url;
    }
    Map<String, String> urlParams = Uri
        .parse(url)
        ?.queryParameters;
    if (urlParams != null && urlParams.isNotEmpty) {
      urlParams.forEach((key, value) {
        if (key == null || key.isEmpty || value == null || value.isEmpty) {
          return;
        }
        if (!params.containsKey(key)) {
          params[key] = value;
        }
      });
      return url.split("?")[0];
    }
    return url;
  }
}

/// 请求结果对象
class HttpResult<T> {
  final ResultStatus status;
  final T data;
  final dynamic error;

  HttpResult(this.status, {this.data, this.error});
}
